@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.31 1997/05/09 04:25:48 mann Exp $
+ * $Id: backend.h,v 1.38 1998/06/13 03:27:14 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -45,12 +45,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * ------------------------------------------------------------------------
  */
+#ifndef _BACKEND
+#define _BACKEND
+
 #include "lists.h"
+#include "frontend.h"
 
 extern GameMode gameMode;
 extern int pausing, cmailMsgLoaded, flipView, ics_bughouse, ics_suicide;
+extern char white_holding[], black_holding[];
+extern int currentMove, backwardMostMove, blackPlaysFirst, analysisSupport;
 extern FILE *debugFP;
 extern char* programVersion;
+extern ProcRef firstProgramPR, secondProgramPR;
+extern Board boards[];
 
 void TimeDelay P((long ms));
 void SendMultiLineToICS P(( char *text ));
@@ -60,6 +68,7 @@ void SetBlackToPlayEvent P((void));
 void InitBackEnd1 P((void));
 void InitBackEnd2 P((void));
 int IsPromotion P((int fromX, int fromY, int toX, int toY));
+int PieceForSquare P((int x, int y));
 int OKToStartUserMove P((int x, int y));
 void Reset P((int redraw));
 void ResetGameEvent P((void));
@@ -68,6 +77,7 @@ int CmailLoadGame P((FILE *f, int n, char *title, int useList));
 int ReloadGame P((int offset));
 int SaveGame P((FILE *f, int dummy, char *dummy2));
 int LoadPosition P((FILE *f, int n, char *title));
+int ReloadPosition P((int offset));
 int SavePosition P((FILE *f, int dummy, char *dummy2));
 void EditPositionEvent P((void));
 void FlipViewEvent P((void));
@@ -95,6 +105,7 @@ void AdjournEvent P((void));
 void ResignEvent P((void));
 void StopObservingEvent P((void));
 void StopExaminingEvent P((void));
+void PonderNextMoveEvent P((int newState));
 void ShowThinkingEvent P((int newState));
 void PeriodicUpdatesEvent P((int newState));
 void HintEvent P((void));
@@ -125,6 +136,8 @@ void AnalyzeFileEvent P((void));
 void DoEcho P((void));
 void DontEcho P((void));
 void TidyProgramName P((char *prog, char *host, char *buf));
+void AskQuestionEvent P((char *title, char *question,
+			 char *replyPrefix, char *which));
 
 char *StrStr P((char *string, char *match));
 char *StrCaseStr P((char *string, char *match));
@@ -170,3 +183,5 @@ char *GameListLine P((int, GameInfo *));
 
 extern char* StripHighlight P((char *));  /* returns static data */
 extern char* StripHighlightAndTitle P((char *));  /* returns static data */
+
+#endif /* _BACKEND */
