@@ -1,6 +1,6 @@
 /*
  * common.h -- Common definitions for X and Windows NT versions of XBoard
- * $Id: common.h,v 1.47 1997/05/17 07:33:03 mann Exp $
+ * $Id: common.h,v 1.61 1998/06/21 01:12:29 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -107,7 +107,7 @@ int pclose(FILE *);
 #define SECOND_HOST		"localhost"
 #define TELNET_PROGRAM          "telnet"
 #define MATCH_MODE		"False"
-#define INIT_STRING		"new\nbeep\nrandom\nhard\n"
+#define INIT_STRING		"new\nrandom\n"
 #define WHITE_STRING		"white\ngo\n"
 #define BLACK_STRING		"black\ngo\n"
 #define REUSE_CHESS_PROGRAMS    1
@@ -116,12 +116,14 @@ int pclose(FILE *);
 #define BLACK_PIECE_COLOR	"#202020"
 #define LIGHT_SQUARE_COLOR	"#C8C365"
 #define DARK_SQUARE_COLOR	"#77A26D"
+#define JAIL_SQUARE_COLOR       "#808080"
+#define HIGHLIGHT_SQUARE_COLOR	"#FFFF00"
 #define BELLCHAR                '\007'
 #define NULLCHAR                '\000'
 
 typedef enum {
     BeginningOfGame, MachinePlaysWhite, MachinePlaysBlack,
-	AnalyzeMode, AnalyzeFile, TwoMachinesPlay,
+    AnalyzeMode, AnalyzeFile, TwoMachinesPlay,
     EditGame, PlayFromGameFile, EndOfGame, EditPosition,
     IcsIdle, IcsPlayingWhite, IcsPlayingBlack, IcsObserving,
     IcsExamining
@@ -130,7 +132,7 @@ typedef enum {
 typedef enum {
     WhitePawn, WhiteKnight, WhiteBishop, WhiteRook, WhiteQueen, WhiteKing,
     BlackPawn, BlackKnight, BlackBishop, BlackRook, BlackQueen, BlackKing,
-    EmptySquare,
+    EmptySquare, 
     ClearBoard, WhitePlay, BlackPlay /*for use on EditPosition menus*/
   } ChessSquare;
 
@@ -139,23 +141,26 @@ typedef ChessSquare Board[BOARD_SIZE][BOARD_SIZE];
 typedef enum {
     WhiteKingSideCastle = 1, WhiteQueenSideCastle,
     WhiteKingSideCastleWild, WhiteQueenSideCastleWild,
-    WhitePromotionKnight, WhitePromotionBishop,
-    WhitePromotionRook, WhitePromotionQueen,
-    WhitePromotionKing, BlackPromotionKnight,
-    BlackPromotionBishop, BlackPromotionRook,
-    BlackPromotionQueen, BlackPromotionKing,
+    WhiteHSideCastleFR, WhiteASideCastleFR, 
     BlackKingSideCastle, BlackQueenSideCastle,
     BlackKingSideCastleWild, BlackQueenSideCastleWild,
+    BlackHSideCastleFR, BlackASideCastleFR, 
+    WhitePromotionKnight, WhitePromotionBishop,
+    WhitePromotionRook, WhitePromotionQueen, WhitePromotionKing,
+    BlackPromotionKnight, BlackPromotionBishop,
+    BlackPromotionRook, BlackPromotionQueen, BlackPromotionKing,
     WhiteCapturesEnPassant, BlackCapturesEnPassant,
-    WhiteDrop, BlackDrop, NormalMove,
+    WhiteDrop, BlackDrop, 
+    NormalMove, AmbiguousMove, IllegalMove, ImpossibleMove,
     WhiteWins, BlackWins, GameIsDrawn, GameUnfinished,
     GNUChessGame, XBoardGame, MoveNumberOne, 
-    BadMove, Comment, AmbiguousMove, PositionDiagram, ElapsedTime, PGNTag
+    Comment, PositionDiagram, ElapsedTime, PGNTag, NAG
   } ChessMove;
 
 typedef enum {
     ColorShout, ColorSShout, ColorChannel1, ColorChannel, ColorKibitz,
-    ColorTell, ColorChallenge, ColorNormal, ColorNone, NColorClasses
+    ColorTell, ColorChallenge, ColorRequest, ColorNormal, ColorNone, 
+    NColorClasses
 } ColorClass;
 
 typedef struct {
@@ -164,19 +169,25 @@ typedef struct {
     char *blackPieceColor;
     char *lightSquareColor;
     char *darkSquareColor;
+    char *jailSquareColor;
+    char *highlightSquareColor;
 #else
     int whitePieceColor;
     int blackPieceColor;
     int lightSquareColor;
     int darkSquareColor;
+    int jailSquareColor;
+    int highlightSquareColor;
 #endif
     int movesPerSession;
     int timeIncrement;
     char *initString;
-    char *whiteString;
-    char *blackString;
+    char *secondInitString;
     char *firstChessProgram;
     char *secondChessProgram;
+    char *firstDirectory;
+    char *secondDirectory;
+    Boolean firstPlaysBlack;
     Boolean noChessProgram;
     char *firstHost;
     char *secondHost;
@@ -203,6 +214,7 @@ typedef struct {
     int loadPositionIndex;  /* position # within file */
     char *savePositionFile;
     Boolean matchMode;
+    int matchGames;
     Boolean monoMode;
     Boolean debugMode;
     Boolean clockMode;
@@ -212,8 +224,9 @@ typedef struct {
     int searchDepth;
     Boolean showCoords;
     char *clockFont;
-    char *messageFont;
+    char *messageFont; /* WinBoard only */
     char *coordFont;
+    char *font; /* xboard only: all other fonts */
     char *tagsFont; /* WinBoard only */
     char *commentFont; /* WinBoard only */
     char *icsFont; /* WinBoard only */
@@ -225,6 +238,7 @@ typedef struct {
     Boolean oldSaveStyle;
     Boolean quietPlay;
     Boolean showThinking;
+    Boolean ponderNextMove;
     Boolean periodicUpdates;
     Boolean autoObserve;
     Boolean autoComment;
@@ -238,8 +252,6 @@ typedef struct {
     Boolean zippyPlay;
     int flashCount; /* Number of times to flash (xboard only) */
     int flashRate; /* Flashes per second (xboard only)  */
-    Boolean clickClick;	/* If True, use click-click instead of
-			   click-drag-release to move pieces. (xboard only) */
     char *xpmDirectory; /* Path to XPM files to use (xboard only) */
     int msLoginDelay;  /* Delay per character (in msec) while sending
 			  ICS logon script (xboard only) */
@@ -252,8 +264,17 @@ typedef struct {
     char *colorKibitz;
     char *colorTell;
     char *colorChallenge;
+    char *colorRequest;
     char *colorNormal;
-    Boolean reuseChessPrograms;
+    Boolean reuseFirst;
+    Boolean reuseSecond;
+    Boolean animateDragging; /* If True, animate mouse dragging of pieces */
+    Boolean animate;	/* If True, animate non-mouse moves */
+    int animSpeed;	/* Delay in milliseconds between animation frames */
+    Boolean popupMoveErrors;
+    int showJail;
+    Boolean highlightLastMove;
+    Boolean highlightDragging;
 } AppData, *AppDataPtr;
 
 extern AppData appData;
