@@ -1,6 +1,6 @@
 /*
  * frontend.h -- Interface exported by all XBoard front ends
- * $Id: frontend.h,v 1.21 1997/05/04 04:09:20 mann Exp $
+ * $Id: frontend.h,v 1.30 1998/06/21 01:35:03 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -63,6 +63,7 @@ void SetCmailMode P((void));
 void DisplayTitle P((String title));
 void DisplayMessage P((String message, String extMessage));
 void DisplayError P((String message, int error));
+void DisplayMoveError P((String message));
 void DisplayFatalError P((String message, int error, int status));
 void DisplayInformation P((String message));
 void AskQuestion P((String title, String question, String replyPrefix,
@@ -93,7 +94,10 @@ int StopLoadGameTimer P((void));
 void StartLoadGameTimer P((long millisec));
 void AutoSaveGame P((void));
 
-int StartChildProcess P((char *cmdLine, ProcRef *pr));
+typedef void (*DelayedEventCallback) P((void));
+void ScheduleDelayedEvent P((DelayedEventCallback cb, long millisec));
+
+int StartChildProcess P((char *cmdLine, char *dir, ProcRef *pr));
 void DestroyChildProcess P((ProcRef pr));
 void InterruptChildProcess P((ProcRef pr));
 
@@ -103,9 +107,11 @@ int OpenCommPort P((char *name, ProcRef *pr));
 int OpenLoopback P((ProcRef *pr));
 int OpenRcmd P((char *host, char *user, char *cmd, ProcRef *pr));
 
-typedef void (*InputCallback) P((InputSourceRef isr, char *buf, int count, int error));
+typedef void (*InputCallback) P((InputSourceRef isr, VOIDSTAR closure,
+				 char *buf, int count, int error));
 /* pr == NoProc means the local keyboard */
-InputSourceRef AddInputSource P((ProcRef pr, int lineByLine, InputCallback func));
+InputSourceRef AddInputSource P((ProcRef pr, int lineByLine,
+				 InputCallback func, VOIDSTAR closure));
 void RemoveInputSource P((InputSourceRef isr));
 
 /* pr == NoProc means the local display */
@@ -113,7 +119,8 @@ int OutputToProcess P((ProcRef pr, char *message, int count, int *outError));
 int OutputToProcessDelayed P((ProcRef pr, char *message, int count,
 			      int *outError, long msdelay));
 
-void CmailSigHandlerCallBack P((InputSourceRef isr, char *buf, int count, int error));
+void CmailSigHandlerCallBack P((InputSourceRef isr, VOIDSTAR closure,
+				char *buf, int count, int error));
 
 extern ProcRef cmailPR;
 
@@ -131,4 +138,12 @@ void StartAnalysisClock P((void));
 void AnalysisPopUp P((char *title, char *label));
 void AnalysisPopDown P((void));
 
+void AnimateMove P((Board board, int fromX, int fromY, int toX, int toY));
+void SetHighlights P((int fromX, int fromY, int toX, int toY));
+void ClearHighlights P((void));
+
+void ShutDownFrontEnd P((void));
+
+extern char *programName;
+
 #endif
