@@ -1,6 +1,6 @@
 /*
  * xboard.h -- Parameter definitions for X front end
- * $Id: xboard.h,v 1.20 1997/04/13 06:31:29 mann Exp $
+ * $Id: xboard.h,v 1.24 1998/06/13 03:27:14 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -53,9 +53,7 @@
 #define MANPAGE      "xboard.6"
 #define CLOCK_FONT   "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
 #define COORD_FONT   "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
-#define DEFAULT_FONT "*font: -*-helvetica-medium-r-normal--14-*-*-*-*-*-*-*"
-#define TINY_FONT \
-    "*tinyLayout*font: -*-helvetica-medium-r-normal--11-*-*-*-*-*-*-*"
+#define DEFAULT_FONT "-*-helvetica-medium-r-normal--*-*-*-*-*-*-*-*"
 #define COLOR_SHOUT             "green"
 #define COLOR_SSHOUT            "green,black,1"
 #define COLOR_CHANNEL1          "cyan"
@@ -63,6 +61,7 @@
 #define COLOR_KIBITZ            "magenta,black,1"
 #define COLOR_TELL              "yellow,black,1"
 #define COLOR_CHALLENGE         "red,black,1"
+#define COLOR_REQUEST           "red"
 #define COLOR_NORMAL            "default"
 
 typedef struct {
@@ -71,16 +70,26 @@ typedef struct {
     int lineGap;
     int clockFontPxlSize;
     int coordFontPxlSize;
+    int fontPxlSize;
     int smallLayout;
     int tinyLayout;
+    int minScreenSize;
 } SizeDefaults;
 
 #define SIZE_DEFAULTS \
-{ { "Large", 80, 3, 34, 14, 0, 0 }, \
-  { "Medium", 64, 3, 34, 12, 0, 0 }, \
-  { "Small", 40, 2, 20, 10, 1, 0 }, \
-  { "Smaller", 32, 1, 16, 9, 1, 1 }, \
-  { "Tiny", 21, 1, 12, 8, 1, 1 }, \
+{ { "Large",    80, 3, 34, 14, 14, 0, 0, 864 }, \
+  { "Bulky",    72, 3, 34, 12, 14, 0, 0, 864 }, \
+  { "Medium",   64, 3, 34, 12, 14, 0, 0, 768 }, \
+  { "Moderate", 58, 3, 34, 12, 14, 0, 0, 768 }, \
+  { "Average",  54, 2, 30, 11, 12, 0, 0, 600 }, \
+  { "Middling", 49, 2, 24, 10, 12, 0, 0, 600 }, \
+  { "Mediocre", 45, 2, 20, 10, 12, 1, 0, 600 }, \
+  { "Small",    40, 2, 20, 10, 12, 1, 0, 480 }, \
+  { "Slim",     37, 2, 20, 10, 12, 1, 0, 480 }, \
+  { "Petite",   33, 1, 15, 9,  11, 1, 0, 480 }, \
+  { "Dinky",    29, 1, 15, 9,  11, 1, 0, 480 }, \
+  { "Teeny",    25, 1, 12, 8,  11, 1, 1, 480 }, \
+  { "Tiny",     21, 1, 12, 8,  11, 1, 1, 0 }, \
   { NULL, 0, 0, 0, 0, 0, 0 } }
 
 #define BORDER_X_OFFSET 3
