@@ -1,6 +1,6 @@
 /*
  * xedittags.c -- Tags edit window, part of X front end for XBoard
- * $Id: xedittags.c,v 1.4 1995/12/09 01:11:46 mann Exp $
+ * $Id: xedittags.c,v 1.5 1998/05/24 05:14:31 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -25,7 +25,7 @@
  * See the file ChangeLog for a revision history.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <ctype.h>
